@@ -1,16 +1,12 @@
-from __future__ import unicode_literals
-
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
 
-@python_2_unicode_compatible
 class Email(models.Model):
 
     """Model to store outgoing email information"""
 
-    from_email = models.TextField(_("from e-mail"))
+    from_email = models.TextField(_("from email"))
     recipients = models.TextField(_("recipients"))
     subject = models.TextField(_("subject"))
     body = models.TextField(_("body"))
@@ -22,6 +18,6 @@ class Email(models.Model):
         return "{s.recipients}: {s.subject}".format(s=self)
 
     class Meta:
-        verbose_name = _("e-mail")
-        verbose_name_plural = _("e-mails")
+        verbose_name = _("email")
+        verbose_name_plural = _("emails")
         ordering = ('-date_sent',)
